P256Error

Struct P256Error 

pub struct P256Error(/* private fields */);
Wrapper around p256::elliptic_curve::Error that implements PartialEq.

p256::elliptic_curve::Error does not implement PartialEq, which is required by the top-level Error enum. This newtype always returns false for equality comparisons, which is the safe conservative choice for opaque cryptographic errors.