Module serde

Module serde 

serde helpers for types that have no natural serialized form, such as std::time::Instant.

Modules

instant_to_epoch
Serializes a SystemInstant to an approximation of epoch time in the form of an f64 where the integer portion is seconds and the decimal portion is milliseconds.