serde helpers for types that have no natural serialized form, such as std::time::Instant.
Modules
- instant_
to_ epoch - Serializes a
SystemInstantto an approximation of epoch time in the form of anf64where the integer portion is seconds and the decimal portion is milliseconds.